Summary: Utilities for managing ext2, ext3, and ext4 file systems
Name: e2fsprogs
Version: 1.47.0
Release: 2%{?dist}
License: GPLv2
URL: http://e2fsprogs.sourceforge.net/
Source0: https://www.kernel.org/pub/linux/kernel/people/tytso/%{name}/v%{version}/%{name}-%{version}.tar.xz

Patch0: 0001-remove-local-PATH.patch

BuildRequires: make gcc
BuildRequires: fuse-devel libsepol-devel
BuildRequires: libblkid-devel libuuid-devel
BuildRequires: gettext systemd
BuildRequires: pkgconfig, texinfo, libselinux-devel

Requires: e2fsprogs-libs = %{version}-%{release}
Requires: libcom_err = %{version}-%{release}
Requires: libss = %{version}-%{release}


%description
This package contains all of the standard utilities for 
creating, fixing, configuring, and debugging ext2, ext3, and ext4 filesystems. 
Such as e2fsck (used to check an ext2/ext3/ext4 file system, 
most often used after a sudden shutdown), 
mke2fs (used to create an ext2, ext3, or ext4 file system), 
and tune2fs (to adjust various tunable filesystem parameters on ext2/ext3/ext4 filesystems), 


%package libs
Summary: Ext2/3/4 file system specific shared libraries
License: GPLv2 and LGPLv2
Requires: libcom_err = %{version}-%{release}

%description libs
E2fsprogs-libs provides libraries of e2fsprogs package, 
contains libe2p and libext2fs which are used to directly 
access ext2/3/4 file systems from userspace.

%package static
Summary: Ext2/3/4 file system specific static libraries
License: GPLv2 and LGPLv2

%description static
E2fsprogs-static provides all static libraries in e2fsprogs,
including libext2fs, libcom_err, libe2p and libss.


%package devel
Summary: Ext2/3/4 file system specific libraries and headers
License: GPLv2 and LGPLv2
Requires: e2fsprogs-libs = %{version}-%{release}
Requires: libcom_err-devel = %{version}-%{release}
Requires: gawk pkgconfig

%description devel
E2fsprogs-devel provides the libraries and header files needed to
develop ext2/ext3/ext4 file system specific programs.


%package -n libcom_err
Summary: Common error description library
License: MIT

%description -n libcom_err
Libcom_err provides the common error description library of e2fsprogs.


%package -n libcom_err-devel
Summary: Common error description library
License: MIT
Requires: libcom_err = %{version}-%{release}
Requires: pkgconfig

%description -n libcom_err-devel
This package provides the common error description development library and headers of e2fsprogs. 
It contains the compile_et command, used
to convert a table listing error-code names and associated 
messages into a C source file suitable for use with the library.


%package -n libss
Summary: Command line interface parsing library
License: MIT
Requires: libcom_err = %{version}-%{release}

%description -n libss
This package provides a command line interface parsing library of e2fsprogs,
including a tool that parses a command table to generate
a simple command-line interface parser, the include files needed to
compile and use it.


%package -n libss-devel
Summary: Command line interface parsing library
License: MIT
Requires: libss = %{version}-%{release}
Requires: pkgconfig

%description -n libss-devel
This package provides the command line interface parsing (libss) development library
and headers of e2fsprogs. It contains the mk_cmds command, which
parses a command table to generate a simple command-line interface parser.


%package -n e2scrub
Summary: Online Ext4 metadata consistency checking tool and service
License: GPLv2 and LGPLv2
Recommends: sendmail
Requires: systemd
Requires: util-linux
Requires: lvm2
Requires: e2fsprogs = %{version}-%{release}

%description -n e2scrub
This package provides e2scrub script that can check ext2/3/4 file system
metadata consistency while the file system is online. It also containes a
systemd service that can be enabled to do consistency check periodically.

The file system consistency check can be performed online and does not
require the file system to be unmounted. It uses lvm snapshots to do this
which means that it can only be done on file systems that are on a lvm
managed device with some free space available in respective volume group.

%prep
%autosetup -p1

# remove flawed test
rm -rf tests/m_rootdir_acl


%build
%configure CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing" \
	   --enable-elf-shlibs --enable-nls --disable-uuidd --disable-fsck \
	   --disable-e2initrd-helper --disable-libblkid --disable-libuuid \
	   --enable-quota --with-root-prefix=/usr --with-crond-dir=no
%make_build

%install
rm -rf %{buildroot}

%make_install install-libs root_sbindir=%{_sbindir} root_libdir=%{_libdir}

# add w perm to fix install failure in strip phase
chmod +w %{buildroot}%{_libdir}/*.a


%find_lang %{name}

%check
make PRINT_FAILED=yes fullcheck


%files -f %{name}.lang
%license NOTICE
%doc README
%config(noreplace) %{_sysconfdir}/mke2fs.conf
%{_sbindir}/badblocks
%{_sbindir}/debugfs
%{_sbindir}/dumpe2fs
%{_sbindir}/e2fsck
%{_sbindir}/e2image
%{_sbindir}/e2label
%{_sbindir}/e2mmpstatus
%{_sbindir}/e2undo
%{_sbindir}/e4crypt
%{_sbindir}/fsck.ext{2,3,4}
%{_sbindir}/logsave
%{_sbindir}/mke2fs
%{_sbindir}/mkfs.ext{2,3,4}
%{_sbindir}/resize2fs
%{_sbindir}/tune2fs
%{_sbindir}/filefrag
%{_sbindir}/e2freefrag
%{_sbindir}/e4defrag
%{_sbindir}/mklost+found
%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/fuse2fs
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/fuse2fs.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man5/ext{2,3,4}.5*
%{_mandir}/man5/e2fsck.conf.5*
%{_mandir}/man5/mke2fs.conf.5*
%{_mandir}/man8/badblocks.8*
%{_mandir}/man8/debugfs.8*
%{_mandir}/man8/dumpe2fs.8*
%{_mandir}/man8/e2fsck.8*
%{_mandir}/man8/e4crypt.8*
%{_mandir}/man8/filefrag.8*
%{_mandir}/man8/e2freefrag.8*
%{_mandir}/man8/e4defrag.8*
%{_mandir}/man8/fsck.ext{2,3,4}.8*
%{_mandir}/man8/e2image.8*
%{_mandir}/man8/e2label.8*
%{_mandir}/man8/e2mmpstatus.8*
%{_mandir}/man8/e2undo.8*
%{_mandir}/man8/logsave.8*
%{_mandir}/man8/mke2fs.8*
%{_mandir}/man8/mkfs.ext{2,3,4}.8*
%{_mandir}/man8/mklost+found.8*
%{_mandir}/man8/resize2fs.8*
%{_mandir}/man8/tune2fs.8*


%files libs
%license NOTICE
%{_libdir}/libe2p.so.*
%{_libdir}/libext2fs.so.*

%files static
%license NOTICE
%{_libdir}/*.a

%files devel
%{_libdir}/libe2p.so
%{_libdir}/libext2fs.so
%{_libdir}/pkgconfig/e2p.pc
%{_libdir}/pkgconfig/ext2fs.pc
%{_infodir}/libext2fs.info*
%{_includedir}/e2p
%{_includedir}/ext2fs

%files -n libcom_err
%license NOTICE
%{_libdir}/libcom_err.so.*

%files -n libcom_err-devel
%{_bindir}/compile_et
%{_libdir}/libcom_err.so
%{_libdir}/pkgconfig/com_err.pc
%{_datadir}/et
%{_includedir}/et
%{_includedir}/com_err.h
%{_mandir}/man1/compile_et.1*
%{_mandir}/man3/com_err.3*

%files -n libss
%license NOTICE
%{_libdir}/libss.so.*

%files -n libss-devel
%{_bindir}/mk_cmds
%{_libdir}/libss.so
%{_datadir}/ss
%{_includedir}/ss
%{_mandir}/man1/mk_cmds.1*
%{_libdir}/pkgconfig/ss.pc

%files -n e2scrub
%config(noreplace) %{_sysconfdir}/e2scrub.conf
%{_sbindir}/e2scrub
%{_sbindir}/e2scrub_all
%{_libdir}/e2fsprogs/e2scrub_fail
%{_unitdir}/e2scrub@.service
%{_unitdir}/e2scrub_all.service
%{_unitdir}/e2scrub_all.timer
%{_unitdir}/e2scrub_fail@.service
%{_unitdir}/e2scrub_reap.service
%{_prefix}/lib/udev/rules.d/96-e2scrub.rules
%{_mandir}/man8/e2scrub.8*
%{_mandir}/man8/e2scrub_all.8*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.47.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 31 2023 Shuo Wang <abushwang@tencent.com> - 1.47.0-1
- update to 1.47.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.46.5-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.46.5-2
- Rebuilt for OpenCloudOS Stream 23

* Tue May 24 2022 Yi Lin <nilusyi@tencent.com> - 1.46.5-1
- package init.
